* mln/core/faces_psite.hh,
* mln/core/image/complex_image.hh,
* mln/core/internal/p_complex_piter_base.hh,
* mln/core/internal/site_set_base.hh,
* mln/core/site_set/complex_psite.hh,
* mln/core/site_set/p_complex.hh,
* mln/geom/complex_geometry.hh,
* mln/topo/adj_higher_dim_connected_n_face_iter.hh,
* mln/topo/adj_higher_face_iter.hh,
* mln/topo/adj_lower_dim_connected_n_face_iter.hh,
* mln/topo/adj_lower_face_iter.hh,
* mln/topo/adj_lower_higher_face_iter.hh,
* mln/topo/attic/faces_iter.hh,
* mln/topo/center_only_iter.hh,
* mln/topo/centered_iter_adapter.hh,
* mln/topo/face_iter.hh,
* mln/topo/internal/complex_iterator_base.hh,
* mln/topo/internal/complex_relative_iterator_base.hh,
* mln/topo/internal/complex_relative_iterator_sequence.hh,
* mln/topo/internal/complex_set_iterator_base.hh,
* mln/topo/n_face_iter.hh,
* mln/topo/static_n_face_iter.hh:
Here.
---
milena/ChangeLog | 28 ++++++++++++++++++++
milena/mln/core/faces_psite.hh | 6 ++--
milena/mln/core/image/complex_image.hh | 7 ++---
milena/mln/core/internal/p_complex_piter_base.hh | 8 +++---
milena/mln/core/internal/site_set_base.hh | 4 +-
milena/mln/core/site_set/complex_psite.hh | 4 +-
milena/mln/core/site_set/p_complex.hh | 4 +-
milena/mln/geom/complex_geometry.hh | 6 ++--
.../topo/adj_higher_dim_connected_n_face_iter.hh | 4 +-
milena/mln/topo/adj_higher_face_iter.hh | 4 +-
.../topo/adj_lower_dim_connected_n_face_iter.hh | 4 +-
milena/mln/topo/adj_lower_face_iter.hh | 4 +-
milena/mln/topo/adj_lower_higher_face_iter.hh | 4 +-
milena/mln/topo/attic/faces_iter.hh | 8 +++---
milena/mln/topo/center_only_iter.hh | 2 +-
milena/mln/topo/centered_iter_adapter.hh | 8 +++---
milena/mln/topo/face_iter.hh | 4 +-
milena/mln/topo/internal/complex_iterator_base.hh | 4 +-
.../internal/complex_relative_iterator_base.hh | 18 ++++++------
.../internal/complex_relative_iterator_sequence.hh | 6 ++--
.../mln/topo/internal/complex_set_iterator_base.hh | 4 +-
milena/mln/topo/n_face_iter.hh | 4 +-
milena/mln/topo/static_n_face_iter.hh | 8 +++---
23 files changed, 90 insertions(+), 63 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 2495d44..0f3a8a2 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,33 @@
2009-06-09 Roland Levillain <roland(a)lrde.epita.fr>
+ Stop using \arg instead of \param or \tparam in documentation.
+
+ * mln/core/faces_psite.hh,
+ * mln/core/image/complex_image.hh,
+ * mln/core/internal/p_complex_piter_base.hh,
+ * mln/core/internal/site_set_base.hh,
+ * mln/core/site_set/complex_psite.hh,
+ * mln/core/site_set/p_complex.hh,
+ * mln/geom/complex_geometry.hh,
+ * mln/topo/adj_higher_dim_connected_n_face_iter.hh,
+ * mln/topo/adj_higher_face_iter.hh,
+ * mln/topo/adj_lower_dim_connected_n_face_iter.hh,
+ * mln/topo/adj_lower_face_iter.hh,
+ * mln/topo/adj_lower_higher_face_iter.hh,
+ * mln/topo/attic/faces_iter.hh,
+ * mln/topo/center_only_iter.hh,
+ * mln/topo/centered_iter_adapter.hh,
+ * mln/topo/face_iter.hh,
+ * mln/topo/internal/complex_iterator_base.hh,
+ * mln/topo/internal/complex_relative_iterator_base.hh,
+ * mln/topo/internal/complex_relative_iterator_sequence.hh,
+ * mln/topo/internal/complex_set_iterator_base.hh,
+ * mln/topo/n_face_iter.hh,
+ * mln/topo/static_n_face_iter.hh:
+ Here.
+
+2009-06-09 Roland Levillain <roland(a)lrde.epita.fr>
+
Typos in comments.
* mln/core/image/complex_image.hh (complex_image<D, G, V>::lvalue)
diff --git a/milena/mln/core/faces_psite.hh b/milena/mln/core/faces_psite.hh
index 2d4121e..d8d7573 100644
--- a/milena/mln/core/faces_psite.hh
+++ b/milena/mln/core/faces_psite.hh
@@ -49,9 +49,9 @@ namespace mln
/// \brief Point site associated to a mln::p_faces.
///
- /// \arg \p N The dimension of the face associated to this psite.
- /// \arg \p D The dimension of the complex this psite belongs to.
- /// \arg \p P The type of point associated to this psite.
+ /// \tparam N The dimension of the face associated to this psite.
+ /// \tparam D The dimension of the complex this psite belongs to.
+ /// \tparam P The type of point associated to this psite.
template <unsigned N, unsigned D, typename P>
class faces_psite
: public internal::pseudo_site_base_< const P&,
diff --git a/milena/mln/core/image/complex_image.hh
b/milena/mln/core/image/complex_image.hh
index 56bdeea..b1788c3 100644
--- a/milena/mln/core/image/complex_image.hh
+++ b/milena/mln/core/image/complex_image.hh
@@ -116,12 +116,11 @@ namespace mln
///
/// Values attached to each face of the complex.
///
- /// \arg p D The dimension of the complex.
- /// \arg p G The geometry type of the complex.
- /// \arg p V The value type of the image.
+ /// \tparam D The dimension of the complex.
+ /// \tparam G The geometry type of the complex.
+ /// \tparam V The value type of the image.
///
/// \ingroup modimageconcrete
- //
template <unsigned D, typename G, typename V>
class complex_image
: public internal::image_primary< V, p_complex<D, G>,
diff --git a/milena/mln/core/internal/p_complex_piter_base.hh
b/milena/mln/core/internal/p_complex_piter_base.hh
index 2070aa8..6d7f5f6 100644
--- a/milena/mln/core/internal/p_complex_piter_base.hh
+++ b/milena/mln/core/internal/p_complex_piter_base.hh
@@ -51,10 +51,10 @@ namespace mln
/// \brief Factoring class for iterators on mln::p_complex.
///
- /// \arg \p I The type of the underlying complex iterator.
- /// \arg \p S The associated site set type.
- /// \arg \p P The associated site type.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam I The type of the underlying complex iterator.
+ /// \tparam S The associated site set type.
+ /// \tparam P The associated site type.
+ /// \tparam E The type exact type of the iterator.
template <typename I, typename S, typename P, typename E>
class p_complex_piter_base_
: public internal::site_set_iterator_base< S, E >
diff --git a/milena/mln/core/internal/site_set_base.hh
b/milena/mln/core/internal/site_set_base.hh
index fffdec2..076d480 100644
--- a/milena/mln/core/internal/site_set_base.hh
+++ b/milena/mln/core/internal/site_set_base.hh
@@ -44,10 +44,10 @@ namespace mln
/// A base class for site set classes.
///
- /// \arg \p P The psite type of what is ``contained'' in the site
+ /// \tparam P The psite type of what is ``contained'' in the site
/// set, not the psite of the site set (which is
/// different, and defined by the site set itself).
- /// \arg \p E The exact type of the site set.
+ /// \tparam E The exact type of the site set.
template <typename P, typename E>
struct site_set_base_ : public Site_Set<E>
{
diff --git a/milena/mln/core/site_set/complex_psite.hh
b/milena/mln/core/site_set/complex_psite.hh
index 159645e..9e150cc 100644
--- a/milena/mln/core/site_set/complex_psite.hh
+++ b/milena/mln/core/site_set/complex_psite.hh
@@ -54,8 +54,8 @@ namespace mln
/// \brief Point site associated to a mln::p_complex.
///
- /// \arg \p D The dimension of the complex this psite belongs to.
- /// \arg \p G The geometry of the complex.
+ /// \tparam D The dimension of the complex this psite belongs to.
+ /// \tparam G The geometry of the complex.
template <unsigned D, typename G>
class complex_psite
: public internal::pseudo_site_base_< const mln_site(G)&, complex_psite<D,
G> >
diff --git a/milena/mln/core/site_set/p_complex.hh
b/milena/mln/core/site_set/p_complex.hh
index 225a70d..c5d2c36 100644
--- a/milena/mln/core/site_set/p_complex.hh
+++ b/milena/mln/core/site_set/p_complex.hh
@@ -105,8 +105,8 @@ namespace mln
/** A complex psite set based on the N-faces of a complex
of dimension \p D (a \p D-complex).
- \arg \p D The dimension of the complex.
- \arg \p G A function object type, associating localization
+ \tparam D The dimension of the complex.
+ \tparam G A function object type, associating localization
information (geometry) to each face of the complex.
\see mln::geom::complex_geometry. */
/// \brief A complex psite set based on the N-faces of a complex.
diff --git a/milena/mln/topo/adj_higher_dim_connected_n_face_iter.hh
b/milena/mln/topo/adj_higher_dim_connected_n_face_iter.hh
index fab364b..034f139 100644
--- a/milena/mln/topo/adj_higher_dim_connected_n_face_iter.hh
+++ b/milena/mln/topo/adj_higher_dim_connected_n_face_iter.hh
@@ -59,7 +59,7 @@ namespace mln
/// \brief Forward iterator on all the n-faces sharing an adjacent
/// (n+1)-face with a (reference) n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_higher_dim_connected_n_face_fwd_iter
@@ -98,7 +98,7 @@ namespace mln
/// \brief Backward iterator on all the n-faces sharing an adjacent
/// (n+1)-face with a (reference) n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_higher_dim_connected_n_face_bkd_iter
diff --git a/milena/mln/topo/adj_higher_face_iter.hh
b/milena/mln/topo/adj_higher_face_iter.hh
index 69028cd..21f6d34 100644
--- a/milena/mln/topo/adj_higher_face_iter.hh
+++ b/milena/mln/topo/adj_higher_face_iter.hh
@@ -65,7 +65,7 @@ namespace mln
/// \brief Forward iterator on all the adjacent (n+1)-faces of the
/// n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_higher_face_fwd_iter
@@ -99,7 +99,7 @@ namespace mln
/// \brief Backward iterator on all the adjacent (n+1)-faces of
/// the n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_higher_face_bkd_iter
diff --git a/milena/mln/topo/adj_lower_dim_connected_n_face_iter.hh
b/milena/mln/topo/adj_lower_dim_connected_n_face_iter.hh
index c0403d8..d493ea9 100644
--- a/milena/mln/topo/adj_lower_dim_connected_n_face_iter.hh
+++ b/milena/mln/topo/adj_lower_dim_connected_n_face_iter.hh
@@ -59,7 +59,7 @@ namespace mln
/// \brief Forward iterator on all the n-faces sharing an adjacent
/// (n-1)-face with a (reference) n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_lower_dim_connected_n_face_fwd_iter
@@ -98,7 +98,7 @@ namespace mln
/// \brief Backward iterator on all the n-faces sharing an adjacent
/// (n-1)-face with a (reference) n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_lower_dim_connected_n_face_bkd_iter
diff --git a/milena/mln/topo/adj_lower_face_iter.hh
b/milena/mln/topo/adj_lower_face_iter.hh
index 9bcaba5..e7010db 100644
--- a/milena/mln/topo/adj_lower_face_iter.hh
+++ b/milena/mln/topo/adj_lower_face_iter.hh
@@ -66,7 +66,7 @@ namespace mln
/// \brief Forward iterator on all the adjacent (n-1)-faces of the
/// n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_lower_face_fwd_iter
@@ -101,7 +101,7 @@ namespace mln
/// \brief Backward iterator on all the adjacent (n-1)-faces of
/// the n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class adj_lower_face_bkd_iter
diff --git a/milena/mln/topo/adj_lower_higher_face_iter.hh
b/milena/mln/topo/adj_lower_higher_face_iter.hh
index 9e261fa..2ed4abd 100644
--- a/milena/mln/topo/adj_lower_higher_face_iter.hh
+++ b/milena/mln/topo/adj_lower_higher_face_iter.hh
@@ -66,7 +66,7 @@ namespace mln
/// Forward iterator on all the adjacent (n-1)-faces and
/// (n+1)-faces of the n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
template <unsigned D>
class adj_lower_higher_face_fwd_iter
: public
internal::complex_relative_iterator_sequence<adj_lower_face_fwd_iter<D>,
@@ -97,7 +97,7 @@ namespace mln
/// Forward iterator on all the adjacent (n-1)-faces and
/// (n+1)-faces of the n-face of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
template <unsigned D>
class adj_lower_higher_face_bkd_iter
: public
internal::complex_relative_iterator_sequence<adj_higher_face_bkd_iter<D>,
diff --git a/milena/mln/topo/attic/faces_iter.hh b/milena/mln/topo/attic/faces_iter.hh
index b0765d5..eca6f40 100644
--- a/milena/mln/topo/attic/faces_iter.hh
+++ b/milena/mln/topo/attic/faces_iter.hh
@@ -45,8 +45,8 @@ namespace mln
/// \brief Forward iterator on all the faces of a mln::complex<D>.
///
- /// \arg \p N The dimension of the face associated to this iterator.
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam N The dimension of the face associated to this iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class faces_fwd_iter_
: public internal::complex_set_iterator_base< n_face<N, D>,
@@ -92,8 +92,8 @@ namespace mln
/// \brief Backward iterator on all the faces of a mln::complex<D>.
///
- /// \arg \p N The dimension of the face associated to this iterator.
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam N The dimension of the face associated to this iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class faces_bkd_iter_
: public internal::complex_set_iterator_base< n_face<N, D>,
diff --git a/milena/mln/topo/center_only_iter.hh b/milena/mln/topo/center_only_iter.hh
index 46677eb..ff072aa 100644
--- a/milena/mln/topo/center_only_iter.hh
+++ b/milena/mln/topo/center_only_iter.hh
@@ -54,7 +54,7 @@ namespace mln
/** \brief Iterator on all the adjacent (n-1)-faces of the n-face
of an mln::complex<D>.
- \arg \p D The dimension of the complex this iterator belongs to.
+ \tparam D The dimension of the complex this iterator belongs to.
mln::topo::center_only_iter inherits from
mln::topo::internal::forward_complex_relative_iterator_base,
diff --git a/milena/mln/topo/centered_iter_adapter.hh
b/milena/mln/topo/centered_iter_adapter.hh
index 32f8e60..4a6e0cc 100644
--- a/milena/mln/topo/centered_iter_adapter.hh
+++ b/milena/mln/topo/centered_iter_adapter.hh
@@ -51,8 +51,8 @@ namespace mln
/// \brief Backward complex relative iterator adapters adding the
/// central (reference) point to the set of iterated faces.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
- /// \arg \p I The adapated complex relative iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
+ /// \tparam I The adapated complex relative iterator.
template <unsigned D, typename I>
class centered_fwd_iter_adapter
: public internal::complex_relative_iterator_sequence<
center_only_iter<D>,
@@ -85,8 +85,8 @@ namespace mln
/// \brief Forward complex relative iterator adapters adding the
/// central (reference) point to the set of iterated faces.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
- /// \arg \p I The adapated complex relative iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
+ /// \tparam I The adapated complex relative iterator.
template <unsigned D, typename I>
class centered_bkd_iter_adapter
: public internal::complex_relative_iterator_sequence< I,
diff --git a/milena/mln/topo/face_iter.hh b/milena/mln/topo/face_iter.hh
index 6cae5b6..c78500a 100644
--- a/milena/mln/topo/face_iter.hh
+++ b/milena/mln/topo/face_iter.hh
@@ -63,7 +63,7 @@ namespace mln
/// \brief Forward iterator on all the faces of an
/// mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class face_fwd_iter
@@ -106,7 +106,7 @@ namespace mln
/// \brief Backward iterator on all the faces of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class face_bkd_iter
diff --git a/milena/mln/topo/internal/complex_iterator_base.hh
b/milena/mln/topo/internal/complex_iterator_base.hh
index 0ae125e..bc8f26e 100644
--- a/milena/mln/topo/internal/complex_iterator_base.hh
+++ b/milena/mln/topo/internal/complex_iterator_base.hh
@@ -72,8 +72,8 @@ namespace mln
/// Factoring class for iterators on mln::complex.
///
- /// \arg \p F The type of the face handle.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam F The type of the face handle.
+ /// \tparam E The type exact type of the iterator.
template <typename F, typename E>
class complex_iterator_base : public Iterator<E>
{
diff --git a/milena/mln/topo/internal/complex_relative_iterator_base.hh
b/milena/mln/topo/internal/complex_relative_iterator_base.hh
index 7867b50..58d6ee0 100644
--- a/milena/mln/topo/internal/complex_relative_iterator_base.hh
+++ b/milena/mln/topo/internal/complex_relative_iterator_base.hh
@@ -77,9 +77,9 @@ namespace mln
/// Factoring class for relative iterators on mln::complex.
///
- /// \arg \p C The type of the center face handle.
- /// \arg \p F The type of the face handle.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam C The type of the center face handle.
+ /// \tparam F The type of the face handle.
+ /// \tparam E The type exact type of the iterator.
template <typename C, typename F, typename E>
class complex_relative_iterator_base :
public complex_iterator_base<F, E>
@@ -130,9 +130,9 @@ namespace mln
/// Factoring class for forward relative iterators on
/// mln::complex.
///
- /// \arg \p C The type of the center face handle.
- /// \arg \p F The type of the face handle.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam C The type of the center face handle.
+ /// \tparam F The type of the face handle.
+ /// \tparam E The type exact type of the iterator.
template <typename C, typename F, typename E>
class forward_complex_relative_iterator_base
: public complex_relative_iterator_base<C, F, E>
@@ -181,9 +181,9 @@ namespace mln
/// Factoring class for backward relative iterators on
/// mln::complex.
///
- /// \arg \p C The type of the center face handle.
- /// \arg \p F The type of the face handle.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam C The type of the center face handle.
+ /// \tparam F The type of the face handle.
+ /// \tparam E The type exact type of the iterator.
template <typename C, typename F, typename E>
class backward_complex_relative_iterator_base
: public complex_relative_iterator_base<C, F, E>
diff --git a/milena/mln/topo/internal/complex_relative_iterator_sequence.hh
b/milena/mln/topo/internal/complex_relative_iterator_sequence.hh
index b788cc4..fda267c 100644
--- a/milena/mln/topo/internal/complex_relative_iterator_sequence.hh
+++ b/milena/mln/topo/internal/complex_relative_iterator_sequence.hh
@@ -62,9 +62,9 @@ namespace mln
/// The first relative iterator is used, and when it becomes
/// invalid, the second one is used.
///
- /// \arg \p I1 The type of the first relative iterator.
- /// \arg \p I2 The type of the second relative iterator.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam I1 The type of the first relative iterator.
+ /// \tparam I2 The type of the second relative iterator.
+ /// \tparam E The type exact type of the iterator.
template <typename I1, typename I2, typename E>
class complex_relative_iterator_sequence : public Iterator<E>
{
diff --git a/milena/mln/topo/internal/complex_set_iterator_base.hh
b/milena/mln/topo/internal/complex_set_iterator_base.hh
index c43fe12..85e3cd1 100644
--- a/milena/mln/topo/internal/complex_set_iterator_base.hh
+++ b/milena/mln/topo/internal/complex_set_iterator_base.hh
@@ -50,8 +50,8 @@ namespace mln
/// Factoring class for (set) iterators on mln::complex.
///
- /// \arg \p F The type of the face handle.
- /// \arg \p E The type exact type of the iterator.
+ /// \tparam F The type of the face handle.
+ /// \tparam E The type exact type of the iterator.
template <typename F, typename E>
class complex_set_iterator_base : public complex_iterator_base<F, E>
{
diff --git a/milena/mln/topo/n_face_iter.hh b/milena/mln/topo/n_face_iter.hh
index cdd5721..4cdb091 100644
--- a/milena/mln/topo/n_face_iter.hh
+++ b/milena/mln/topo/n_face_iter.hh
@@ -66,7 +66,7 @@ namespace mln
/// \brief Forward iterator on all the faces of an
/// mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned D>
class n_face_fwd_iter
@@ -122,7 +122,7 @@ namespace mln
/// Backward iterator on all the faces of an mln::complex<D>.
///
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam D The dimension of the complex this iterator belongs to.
template <unsigned D>
class n_face_bkd_iter
: public internal::complex_set_iterator_base< topo::face<D>,
diff --git a/milena/mln/topo/static_n_face_iter.hh
b/milena/mln/topo/static_n_face_iter.hh
index 4a78ecc..21a7639 100644
--- a/milena/mln/topo/static_n_face_iter.hh
+++ b/milena/mln/topo/static_n_face_iter.hh
@@ -48,8 +48,8 @@ namespace mln
/// \brief Forward iterator on all the \p N-faces of a
/// mln::complex<D>.
///
- /// \arg \p N The dimension of the face associated to this iterator.
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam N The dimension of the face associated to this iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned N, unsigned D>
class static_n_face_fwd_iter
@@ -94,8 +94,8 @@ namespace mln
/// \brief Backward iterator on all the \p N-faces of a
/// mln::complex<D>.
///
- /// \arg \p N The dimension of the face associated to this iterator.
- /// \arg \p D The dimension of the complex this iterator belongs to.
+ /// \tparam N The dimension of the face associated to this iterator.
+ /// \tparam D The dimension of the complex this iterator belongs to.
//
template <unsigned N, unsigned D>
class static_n_face_bkd_iter
diff --git a/milena/mln/geom/complex_geometry.hh b/milena/mln/geom/complex_geometry.hh
index b2f7320..f1c604c 100644
--- a/milena/mln/geom/complex_geometry.hh
+++ b/milena/mln/geom/complex_geometry.hh
@@ -70,8 +70,8 @@ namespace mln
where the locations of each 0-face is stored. Faces of higher
dimensions are computed.
- \arg \p D The dimension of the complex.
- \arg \p P The type of the location of a 0-face.
+ \tparam D The dimension of the complex.
+ \tparam P The type of the location of a 0-face.
Locations of 0-face are usually points (hence the \p P above),
but can possibly be any (default-constructible) values.
@@ -115,7 +115,7 @@ namespace mln
{
/// The data stored in a complex_geometry object.
///
/// \arg \p P The type of the location of a 0-face.
template <typename P>
struct complex_geometry_data
{
@@ -115,7 +115,7 @@ namespace mln
/// The data stored in a complex_geometry object.
///
- /// \arg \p P The type of the location of a 0-face.
+ /// \tparam P The type of the location of a 0-face.
template <typename P>
struct complex_geometry_data
--
1.6.1.2